@@ -5,12 +5,13 @@ from functools import wraps
 from typing import Callable
 
 
-def pipeline(dataloader=None, endpoint=None, is_async=False, timeout=None) -> Callable:
-    """Wrapper for inference functions in the users pipeline.
+def pipeline(
+    name: str=None, is_async: bool=False, timeout: int=None
+) -> Callable:
+    """ Wrapper for inference functions in the users pipeline.
 
     Args:
-        dataloader (DataLoader): The dataloader to use for inference.
-        endpoint (str): The endpoint to use for inference.
+        name (str): The name of this pipeline.
         is_async (bool): Whether to use async inference.
         timeout (int): The timeout for inference.
 
@@ -19,7 +20,7 @@ def pipeline(dataloader=None, endpoint=None, is_async=False, timeout=None) -> Ca
     """
 
     def decorator(func: Callable):
-        """Decorator for said function.
+        """ Decorator for said function.
 
         Args:
             func: The users function to decorate
@@ -29,21 +30,15 @@ def pipeline(dataloader=None, endpoint=None, is_async=False, timeout=None) -> Ca
         """
 
         @wraps(func)
-        def wrapper(*args):
-
-            # Load data from dataloader
-            args = list(args)
-            if dataloader is not None:
-                args[-1] = dataloader(args[-1])  # pragma: no cover
+        def wrapper(*args, **kwargs):
 
             # - call locally (in process)
-            response = func(*args)
+            response = func(*args, **kwargs)
 
             return response
 
-        wrapper.is_decorated_ = True
-        wrapper.dataloader_ = dataloader
-        wrapper.endpoint_ = endpoint
+        wrapper.is_decorated_ = True  # Necessary for pipeline discovery
+        wrapper.name_ = name
         wrapper.is_async_ = is_async
         wrapper.timeout_ = timeout
         return wrapper
